@@ -7,19 +7,18 @@ from dateutil import parser
 from datetime import datetime
 from typing import Dict, Optional
 
+from .constants import (
+    API_KEY_CONFIG_KEY,
+    MQL_OVERRIDE_CONFIG_KEY,
+    BEARER_TOKEN_CONFIG_KEY,
+    BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY,
+)
 from .exceptions import AuthException, URLException
 from .interfaces import MQLInterface, BackendInterface
 from .models import User, Organization, ModelKey, UserState
 
 
 class TransformAuth:  # noqa: D
-
-    API_KEY_CONFIG_KEY = "api_key"
-    MQL_OVERRIDE_CONFIG_KEY = "mql_server_url_override"
-    BEARER_TOKEN_CONFIG_KEY = "bearer_token"
-    BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY = "bearer_token_expires_at"
-    MQL_OVERRIDE_CONFIG_KEY = "mql_server_url_override"
-
     def __init__(  # noqa: D
         self, api_key: Optional[str] = None, mql_server_url: Optional[str] = None, override_config: bool = True
     ) -> None:
@@ -35,13 +34,10 @@ class TransformAuth:  # noqa: D
         if mql_server_url is not None:
             self.mql_server_url_config_override = mql_server_url
 
-        # Trigger auth
-        self.auth_header
-
     @property
     def api_key(self) -> Optional[str]:
         """Pull API key from config file by default, also supporting a fallback environment variable TRANSFORM_API_KEY."""
-        config_api_key = self.config._get_config_value(self.API_KEY_CONFIG_KEY)
+        config_api_key = self.config._get_config_value(API_KEY_CONFIG_KEY)
         return config_api_key if config_api_key else os.getenv("TRANSFORM_API_KEY")
 
     @api_key.setter
@@ -53,12 +49,12 @@ class TransformAuth:  # noqa: D
         if not api_key.count("-") == 2:
             raise AuthException
 
-        self.config._set_config_value(self.API_KEY_CONFIG_KEY, api_key)
+        self.config._set_config_value(API_KEY_CONFIG_KEY, api_key)
 
     @property
     def bearer_token(self) -> Optional[str]:
         """Get bearer token from config, if exists."""
-        token = self.config._get_config_value(self.BEARER_TOKEN_CONFIG_KEY)
+        token = self.config._get_config_value(BEARER_TOKEN_CONFIG_KEY)
         if (
             token is not None
             and self.bearer_token_expires_at is not None
@@ -70,28 +66,25 @@ class TransformAuth:  # noqa: D
 
     @bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
-        self.config._set_config_value(self.BEARER_TOKEN_CONFIG_KEY, bearer_token)
+        self.config._set_config_value(BEARER_TOKEN_CONFIG_KEY, bearer_token)
 
     @property
     def bearer_token_expires_at(self) -> Optional[str]:
         """Time that current bearer token will expire, if exists."""
-        return self.config._get_config_value(self.BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
+        return self.config._get_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY)
 
     @bearer_token_expires_at.setter
     def bearer_token_expires_at(self, bearer_token_expires_at: str) -> None:  # noqa: D
-        self.config._set_config_value(self.BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY, bearer_token_expires_at)
+        self.config._set_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY, bearer_token_expires_at)
 
     @property
-    def auth_header(self) -> Dict[str, str]:
-        """Get auth header based on creds in config file. If none, raise exception."""
+    def auth_header(self) -> Optional[Dict[str, str]]:
+        """Get auth header based on creds in config file. If none, return None."""
         if not self.__auth_header:
             if self.api_key is not None:
                 self.__auth_header = {"Authorization": f"X-Api-Key {self.api_key}"}
             elif self.bearer_token is not None:
                 self.__auth_header = {"Authorization": f"Bearer {self.bearer_token}"}
-            else:
-                raise AuthException
-
         return self.__auth_header
 
     @property
@@ -117,16 +110,6 @@ class TransformAuth:  # noqa: D
     def current_model(self) -> Optional[ModelKey]:  # noqa: D
         return self.user_state.current_model
 
-    @property
-    def is_authenticated(self) -> bool:  # noqa: D
-        if self.api_key is not None or self.bearer_token is not None:
-            try:
-                self.user_state  # Will error if not authed with correct method
-                return True
-            except Exception:
-                return False
-        return False
-
     @property
     def mql_server_url_status(self) -> str:  # noqa: D
         return f"Your MQL server is {self.mql_server_url} " + (
@@ -153,14 +136,14 @@ class TransformAuth:  # noqa: D
 
         Overrideable via passing MQL server url at instantiation process for users who need to redirect using a local proxy.
         """
-        return self.config._get_config_value(self.MQL_OVERRIDE_CONFIG_KEY)
+        return self.config._get_config_value(MQL_OVERRIDE_CONFIG_KEY)
 
     @mql_server_url_config_override.setter
     def mql_server_url_config_override(self, mql_server_url: str) -> None:  # noqa: D
         if not mql_server_url:
-            self.config._remove_config_value(self.MQL_OVERRIDE_CONFIG_KEY)
+            self.config._remove_config_value(MQL_OVERRIDE_CONFIG_KEY)
         elif validators.url(mql_server_url, public=False):
-            self.config._set_config_value(self.MQL_OVERRIDE_CONFIG_KEY, mql_server_url)
+            self.config._set_config_value(MQL_OVERRIDE_CONFIG_KEY, mql_server_url)
         else:
             raise URLException(mql_server_url)
 
