@@ -9,6 +9,7 @@ from halo import Halo
 from typing import List, Optional
 
 from log_symbols import LogSymbols
+from packaging.version import parse
 from update_checker import UpdateChecker  # type: ignore
 
 from .cli_context import CLIContext
@@ -295,6 +296,7 @@ def query(
     explain: bool = False,
     web: bool = False,
     debug: bool = False,
+    allow_dynamic_cache: bool = True,
 ) -> None:
     """Create a new MQL query, polls for completion and assembles a DataFrame from the response."""
     if not limit:
@@ -323,6 +325,7 @@ def query(
         limit=limit,
         cache_mode=cache_mode.value if cache_mode else None,
         as_table=as_table,
+        allow_dynamic_cache=allow_dynamic_cache,
     ).query_id
 
     spinner.succeed(f"Query initialized: {query_id}")
@@ -359,7 +362,11 @@ def query(
             df.to_csv(csv, index=False)
             click.echo(f"Successfully written query output to {csv.name}")
         else:
-            click.echo(df.to_markdown(index=False, floatfmt=".2f"))
+            # NOTE: remove `to_string` if no pandas dependency is < 1.0.0
+            if parse(pd.__version__) >= parse("1.0.0"):
+                click.echo(df.to_markdown(index=False, floatfmt=".2f"))
+            else:
+                click.echo(df.to_string(index=False, float_format=lambda x: format(x, ".2f")))
 
     if web:
         click.launch(get_query_logs_url_for_id(query_id))
@@ -594,6 +601,39 @@ def list_materializations(config: CLIContext, search: Optional[str] = None) -> N
         )
 
 
+@cli.command()
+@pass_config
+@click.option("--metric-name", required=True, type=str, help="Metric that is associated with the dimension")
+@click.option("--dimension-name", required=True, type=str, help="Dimension to query")
+@exception_handler
+def get_dimension_values(config: CLIContext, dimension_name: str, metric_name: str) -> None:
+    """List all dimension values that are queryable through materialized tables."""
+    model_key = config.resolve_query_model_key()
+    try:
+        dim_vals = sorted(
+            config.mql.get_dimension_values(metric_name, dimension_name, model_key.id if model_key else None)
+        )
+    except Exception as e:
+        click.echo(
+            textwrap.dedent(
+                f"""\
+                ❌ Failed to query dimension values for dimension {dimension_name} of metric {metric_name}.
+                💡 Ensure that this query can be done via pre-materialized results by creating a
+                       materialization that includes the desired metric and dimension
+
+                    ERROR: {str(e)}
+                """
+            )
+        )
+        exit(1)
+
+    click.echo(
+        f"🌱 We've found {len(dim_vals)} dimension values for dimension {dimension_name} of metric {metric_name}."
+    )
+    for dim_val in dim_vals:
+        click.echo(f"• {click.style(dim_val, bold=True, fg='green')}")
+
+
 @cli.command()
 @pass_config
 @click.option("--search", required=False, type=str, help="Filter available metrics by this search term")
@@ -623,8 +663,8 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
     num_dims_to_show = MAX_LIST_OBJECT_ELEMENTS
     for m in metrics:
         # sort dimensions by whether they're local first(if / then global else local) then the dim name
-        dimensions = sorted(filter(lambda d: "/" not in d, m.dimensions)) + sorted(
-            filter(lambda d: "/" in d, m.dimensions)
+        dimensions = sorted(map(lambda d: d.name, filter(lambda d: "/" not in d.name, m.dimensions))) + sorted(
+            map(lambda d: d.name, filter(lambda d: "/" in d.name, m.dimensions))
         )
         if show_all_dims:
             num_dims_to_show = len(dimensions)
@@ -634,6 +674,21 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
         )
 
 
+@cli.command()
+@pass_config
+@exception_handler
+def list_dimensions(config: CLIContext) -> None:
+    """List all unique dimensions for the Organization."""
+    model_key = config.resolve_query_model_key()
+    dimensions = sorted(config.mql.list_dimensions(model_key.id if model_key else None).values(), key=lambda d: d.name)
+    if not dimensions:
+        click.echo("List of dimensions unavailable.")
+
+    click.echo(f"🌱 We've found {len(dimensions)} unique dimensions for the {config.org.name} organization.")
+    for d in dimensions:
+        click.echo(f"• {click.style(d.name, bold=True, fg='green')}")
+
+
 @cli.command()
 @pass_config
 @click.option("--query-id", required=True, type=str, help="Query ID to stream logs for")
