@@ -12,7 +12,7 @@ from gql import Client, gql  # type: ignore
 from gql.transport.requests import RequestsHTTPTransport  # type: ignore
 
 from transform_tools.validate import upload_configs, ERROR_RESPONSE_PREFIX
-from .constants import DEFAULT_QUERY_TIMEOUT
+from .constants import DEFAULT_QUERY_TIMEOUT, MAX_PAGE_SIZE
 from .exceptions import QueryRuntimeException
 from .utils import resolve_local_commit_info
 from .models import (
@@ -20,6 +20,7 @@ from .models import (
     MqlQueryStatusResp,
     QueryResult,
     CacheMode,
+    Dimension,
     Organization,
     User,
     Materialization,
@@ -96,8 +97,7 @@ class BaseInterface:
                 )
             else:
                 raise
-        finally:
-            logger.debug(f"Query for {' '.join(response.keys())} took {(time.time() - start_time):.2f}s")
+        logger.debug(f"Query for {' '.join(response.keys())} took {(time.time() - start_time):.2f}s")
         return response
 
     @property
@@ -293,6 +293,76 @@ class BackendInterface(BaseInterface):  # noqa: D
         )
         return MQLServerImage.from_gql_dict(self.execute(query)["latestMqlServer"])
 
+    def get_metrics_metadata(self) -> List[Dict[str, Any]]:
+        """Fetch all org metrics' metadata."""
+        query = gql(
+            """
+            query MetricsMetadataQuery ($pageSize: Int!){
+                myOrganization {
+                    metrics (pageSize: $pageSize){
+                        name
+                        description
+                        displayName
+                        tier
+                        userOwners{
+                            user {
+                                userName
+                                isOrgAdmin
+                                email
+                            }
+                        }
+                        teamOwners{
+                            team {
+                                name
+                                memberUsers {
+                                    userName
+                                    isOrgAdmin
+                                    email
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+            """
+        )
+        return self.execute(query, variable_values={"pageSize": MAX_PAGE_SIZE})["myOrganization"]["metrics"]
+
+    def get_metric_metadata_by_name(self, metric_name: str) -> Dict[str, Any]:
+        """Fetch a single org metric metadata."""
+        query = gql(
+            """
+            query MetricMetadataQuery ($metricName: String!) {
+                myOrganization {
+                    metric (name: $metricName){
+                        name
+                        description
+                        displayName
+                        tier
+                        userOwners{
+                            user {
+                                userName
+                                isOrgAdmin
+                                email
+                            }
+                        }
+                        teamOwners{
+                            team {
+                                name
+                                memberUsers {
+                                    userName
+                                    isOrgAdmin
+                                    email
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+            """
+        )
+        return self.execute(query, variable_values={"metricName": metric_name})["myOrganization"]["metric"]
+
 
 class MQLInterface(BaseInterface):  # noqa: D
     def __init__(self, auth_header: Dict[str, str], query_server_url: str) -> None:  # noqa: D
@@ -313,6 +383,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         as_table: Optional[str] = None,
         time_series: bool = True,
         result_format: Optional[str] = None,
+        allow_dynamic_cache: bool = True,
     ) -> Dict[str, Any]:
         return {
             "modelKey": {
@@ -335,6 +406,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             "asTable": as_table,
             "timeSeries": time_series,
             "resultFormat": result_format,
+            "allowDynamicCache": allow_dynamic_cache,
         }
 
     def drop_materialization(  # noqa: D
@@ -508,6 +580,44 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["materializations"]
         ]
 
+    def get_dimension_values(
+        self,
+        metric_name: str,
+        dimension_name: str,
+        allow_dynamic_cache: bool = False,
+        model_key: Optional[ModelKey] = None,
+    ) -> List[str]:
+        """Retrieve all dimension values of a given [metric,dimension].
+
+        NOTE: dynamic caching is disabled (ie., only allowed to retrieve dimension values through materialization)
+        """
+        query = gql(
+            """
+            query DimensionValueQuery($dimensionName: String!, $metricName: String!, $allowDynamicCache: Boolean, $modelKey: ModelKeyInput) {
+                metricByName(modelKey: $modelKey, name: $metricName) {
+                    dimensionValues(dimensionName: $dimensionName, allowDynamicCache: $allowDynamicCache)
+                }
+            }
+            """
+        )
+
+        return self.execute(
+            query,
+            variable_values={
+                "modelKey": {
+                    "organization": model_key.organization_id,
+                    "repo": model_key.repository,
+                    "branch": model_key.branch,
+                    "commit": model_key.commit,
+                }
+                if model_key
+                else None,
+                "dimensionName": dimension_name,
+                "metricName": metric_name,
+                "allowDynamicCache": allow_dynamic_cache,
+            },
+        )["metricByName"]["dimensionValues"]
+
     def get_metrics(self, model_key: Optional[ModelKey] = None) -> List[Metric]:  # noqa: D
         query = gql(
             """
@@ -515,12 +625,27 @@ class MQLInterface(BaseInterface):  # noqa: D
                 metrics(modelKey: $modelKey) {
                     name
                     measures
-                    dimensions
+                    type
+                    typeParams {
+                        numerator
+                        denominator
+                        expr
+                        window
+                    }
+                    constraint
+                    dimensionObjects {
+                        name
+                        identifierName
+                        identifierNames
+                        type
+                        isPrimaryTime
+                        timeGranularity
+                        cardinality
+                    }
                 }
             }
             """
         )
-
         return [
             Metric.from_gql_dict(m)
             for m in self.execute(
@@ -538,14 +663,30 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["metrics"]
         ]
 
-    def get_metric(self, metric_name: str, model_key: Optional[ModelKey] = None):  # noqa: D
+    def get_metric_by_name(self, metric_name: str, model_key: Optional[ModelKey] = None):  # noqa: D
         query = gql(
             """
             query MetricQuery($modelKey: ModelKeyInput, $metricName: String!) {
                 metricByName(modelKey: $modelKey, name: $metricName) {
                     name
                     measures
-                    dimensions
+                    type
+                    typeParams {
+                        numerator
+                        denominator
+                        expr
+                        window
+                    }
+                    constraint
+                    dimensionObjects {
+                        name
+                        identifierName
+                        identifierNames
+                        type
+                        isPrimaryTime
+                        timeGranularity
+                        cardinality
+                    }
                 }
             }
             """
@@ -567,6 +708,40 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["metricByName"]
         )
 
+    def get_dimensions(self, model_key: Optional[ModelKey] = None) -> List[Dimension]:
+        """Get a list of all unique Dimension objects."""
+        query = gql(
+            """
+            query DimensionsQuery($modelKey: ModelKeyInput) {
+                dimensions(modelKey: $modelKey) {
+                    name
+                    identifierName
+                    identifierNames
+                    type
+                    isPrimaryTime
+                    timeGranularity
+                    cardinality
+                }
+            }
+            """
+        )
+        return [
+            Dimension.from_gql_dict(dim)
+            for dim in self.execute(
+                query,
+                variable_values={
+                    "modelKey": {
+                        "organization": model_key.organization_id,
+                        "repo": model_key.repository,
+                        "branch": model_key.branch,
+                        "commit": model_key.commit,
+                    }
+                    if model_key
+                    else None
+                },
+            )["dimensions"]
+        ]
+
     def create_query(  # noqa: D
         self,
         metrics: List[str],
@@ -580,6 +755,7 @@ class MQLInterface(BaseInterface):  # noqa: D
         limit: Optional[str] = None,
         cache_mode: Optional[CacheMode] = None,
         as_table: Optional[str] = None,
+        allow_dynamic_cache: bool = True,
     ) -> str:
         """Implements CreateMqlQuery mutation in MQL/GQL"""
 
@@ -602,6 +778,7 @@ class MQLInterface(BaseInterface):  # noqa: D
                 $timeSeries: Boolean,
                 $resultFormat: ResultFormat,
                 $pctChange: PercentChange,
+                $allowDynamicCache: Boolean,
             ) {
                 createMqlQuery(
                     input: {
@@ -618,6 +795,7 @@ class MQLInterface(BaseInterface):  # noqa: D
                         addTimeSeries: $timeSeries,
                         resultFormat: $resultFormat,
                         pctChange: $pctChange,
+                        allowDynamicCache: $allowDynamicCache
                     }
                 ) {
                     id
@@ -640,6 +818,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             as_table=as_table,
             time_series=time_series,
             result_format=result_format,
+            allow_dynamic_cache=allow_dynamic_cache,
         )
 
         return self.execute(query, variable_values=params)["createMqlQuery"]["id"]
