@@ -122,21 +122,100 @@ class Materialization:
 
 
 @dataclass(frozen=True)
+class UserOwner:
+    """Object to represent a user owner."""
+
+    user_name: str
+    is_org_admin: bool
+    email: str
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, Any]) -> "UserOwner":  # type: ignore [misc] # noqa: D
+        return cls(
+            user_name=_input["userName"],
+            is_org_admin=_input["isOrgAdmin"],
+            email=_input["email"],
+        )
+
+
+@dataclass(frozen=True)
+class TeamOwner:
+    """Object to represent a team owner."""
+
+    name: str
+    users: List[UserOwner]
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, Any]) -> "TeamOwner":  # type: ignore [misc] # noqa: D
+        return cls(
+            name=_input["name"],
+            users=[UserOwner.from_gql_dict(u) for u in _input["memberUsers"]],
+        )
+
+
+class MetricType(Enum):
+    """Metric type Enum."""
+
+    MEASURE_PROXY = "measure_proxy"
+    RATIO = "ratio"
+    EXPR = "expr"
+    CUMULATIVE = "cumulative"
+
+
+@dataclass
+class MetricTypeParams:
+    """Object to represent the type params of a Metric."""
+
+    numerator: Optional[str]
+    denominator: Optional[str]
+    expr: Optional[str]
+    window: Optional[str]
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, Any]) -> "MetricTypeParams":  # type: ignore [misc] # noqa: D
+        return cls(
+            numerator=_input["numerator"],
+            denominator=_input["denominator"],
+            expr=_input["expr"],
+            window=_input["window"],
+        )
+
+
+@dataclass
 class Metric:
     """Object to represent a Metric."""
 
     name: str
     measures: List[str]
-    dimensions: List[str]
+    metric_type: MetricType
+    type_params: MetricTypeParams
+    constraint: Optional[str]
+    dimensions: List["Dimension"]
+    team_owners: Optional[List[TeamOwner]] = None
+    user_owners: Optional[List[UserOwner]] = None
+    display_name: Optional[str] = None
+    description: Optional[str] = None
+    tier: Optional[int] = None
 
     @classmethod
     def from_gql_dict(cls, _input: Dict[str, Any]) -> "Metric":  # type: ignore [misc] # noqa: D
         return cls(
             name=_input["name"],
             measures=_input["measures"],
-            dimensions=_input["dimensions"],
+            metric_type=MetricType(_input["type"].lower()),
+            type_params=MetricTypeParams.from_gql_dict(_input["typeParams"]),
+            constraint=_input["constraint"],
+            dimensions=list({d["name"]: Dimension.from_gql_dict(d) for d in _input["dimensionObjects"]}.values()),
         )
 
+    def input_metadata(self, metadata: Dict[str, Any]) -> None:
+        """Input additional backend metadata."""
+        self.description = metadata["description"]
+        self.display_name = metadata["displayName"]
+        self.tier = metadata["tier"]
+        self.team_owners = [TeamOwner.from_gql_dict(t["team"]) for t in metadata["teamOwners"]]
+        self.user_owners = [UserOwner.from_gql_dict(u["user"]) for u in metadata["userOwners"]]
+
 
 class MqlQueryStatus(Enum):
     """The status of queries submitted for execution in the query manager."""
@@ -195,7 +274,7 @@ class CacheMode(Enum):
     READ = "r"  # use cached datasets but do not write new datasets to cache
     READWRITE = "rw"  # use cached datasets and write new datasets to cache
     WRITE = "w"  # ignore cached datatsets and write new datasets to cache
-    IGNORE = ""  # ignore cache completely, only use configuration files
+    IGNORE = "i"  # ignore cache completely, only use configuration files
 
     @classmethod
     def from_string(cls, string_value: str) -> "CacheMode":  # noqa: D
@@ -315,3 +394,35 @@ class PercentChange(Enum):
     MOM = "mom"  # month-over-month
     QOQ = "qoq"  # quarter-over-quarter
     YOY = "yoy"  # year-over-year
+
+
+class DimensionType(Enum):
+    """Dimension type Enums."""
+
+    CATEGORICAL = "categorical"
+    TIME = "time"
+
+
+@dataclass(frozen=True)
+class Dimension:
+    """Object to represent a Dimension object."""
+
+    name: str
+    identifier_name: str
+    identifier_names: List[str]
+    dimension_type: DimensionType
+    is_primary_time: bool
+    time_granularity: Optional[TimeGranularity]
+    cardinality: Optional[int]
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, str]) -> "Dimension":  # noqa: D
+        return cls(
+            name=_input["name"],
+            identifier_name=_input["identifierName"],
+            identifier_names=_input["identifierNames"],
+            dimension_type=DimensionType(_input["type"].lower()),
+            is_primary_time=_input["isPrimaryTime"],
+            time_granularity=TimeGranularity(_input["timeGranularity"].lower()) if _input["timeGranularity"] else None,
+            cardinality=_input["cardinality"],
+        )
