@@ -6,6 +6,7 @@ from typing import Any, Dict, List, Optional, Tuple
 from .auth import TransformAuth
 from .models import (
     CacheMode,
+    Dimension,
     HealthReportStatus,
     Materialization,
     Metric,
@@ -41,6 +42,7 @@ class MQLClient:
         limit: Optional[str] = None,
         cache_mode: Optional[str] = None,
         as_table: Optional[str] = None,
+        allow_dynamic_cache: bool = True,
     ) -> MqlQueryStatusResp:
         """Builds a query in MQL and returns a MqlQueryStatusResp detailing the results."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
@@ -56,6 +58,7 @@ class MQLClient:
             limit,
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
+            allow_dynamic_cache,
         )
         return self.context.mql_client.get_query_status(query_id)
 
@@ -72,6 +75,7 @@ class MQLClient:
         limit: Optional[str] = None,
         cache_mode: Optional[str] = None,
         as_table: Optional[str] = None,
+        allow_dynamic_cache: bool = True,
     ) -> pd.DataFrame:
         """Builds a query in MQL and returns pandas dataframe of queried result.
 
@@ -92,6 +96,7 @@ class MQLClient:
             limit,
             CacheMode(cache_mode) if cache_mode else None,
             as_table,
+            allow_dynamic_cache,
         )
         return self.get_query_dataframe(query_id)
 
@@ -102,13 +107,18 @@ class MQLClient:
     def list_metrics(self, model_key_id: Optional[int] = None) -> Dict[str, Metric]:
         """Returns a dictionary {metric_name: Metric}."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        metrics = self.context.mql_client.get_metrics(model_key)
-        return {metric.name: metric for metric in metrics}
+        metrics = {m.name: m for m in self.context.mql_client.get_metrics(model_key)}
+        metrics_metadata = self.context.backend_client.get_metrics_metadata()
+        for data in metrics_metadata:
+            metrics[data["name"]].input_metadata(data)
+        return metrics
 
     def get_metric(self, metric_name: str, model_key_id: Optional[int] = None) -> Metric:
         """Retrieve a Metric Object by name."""
         model_key = self.get_model_key(model_key_id) if model_key_id else None
-        return self.context.mql_client.get_metric(metric_name, model_key=model_key)
+        metric = self.context.mql_client.get_metric_by_name(metric_name, model_key=model_key)
+        metric.input_metadata(self.context.backend_client.get_metric_metadata_by_name(metric_name))
+        return metric
 
     def create_materialization(  # noqa: D
         self,
@@ -181,6 +191,11 @@ class MQLClient:
     def health_report(self) -> List[ServerHealthReport]:
         """Performs a health check on all mql servers within the organization and returns List[ServerHealthReport]."""
         servers = self.context.backend_client.get_org_mql_servers()
+        # in the case where the user has a local override, we still want to run a health report
+        if self.context.mql_client.rest_api_url not in [s.url for s in servers]:
+            servers.append(
+                MQLServer(id=0, name="Local Override", url=self.context.mql_client.rest_api_url, is_org_default=False)
+            )
         result = []
         for s in servers:
             test_server = MQLInterface(self.context.auth_header, s.url)
@@ -243,3 +258,16 @@ class MQLClient:
     def latest_mql_image(self) -> MQLServerImage:
         """Retrieves the latest MQL server image."""
         return self.context.backend_client.get_latest_mql_server_image()
+
+    def get_dimension_values(
+        self, metric_name: str, dimension_name: str, model_key_id: Optional[int] = None
+    ) -> List[str]:
+        """Retrieves a list of dimension values given a [metric_name, dimension_name]."""
+        model_key = self.get_model_key(model_key_id) if model_key_id else None
+        return self.context.mql_client.get_dimension_values(metric_name, dimension_name, model_key=model_key)
+
+    def list_dimensions(self, model_key_id: Optional[int] = None) -> Dict[str, Dimension]:
+        """Retrieves a list of all Dimension objects."""
+        model_key = self.get_model_key(model_key_id) if model_key_id else None
+        dimensions = self.context.mql_client.get_dimensions(model_key)
+        return {dim.name: dim for dim in dimensions}
